@@ -58,11 +58,7 @@ Contact::Contact(const Contact &other):
     KContacts::Addressee(other),
     d(new Private(*(other.d)))
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList groups = custom(QStringLiteral("GCALENDAR"), QStringLiteral("groupMembershipInfo")).split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
     const QStringList groups = custom(QStringLiteral("GCALENDAR"), QStringLiteral("groupMembershipInfo")).split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
     for (const QString &group : groups) {
         d->groups.insert(group, false);
     }
@@ -73,11 +69,7 @@ Contact::Contact(const KContacts::Addressee& other):
     KContacts::Addressee(other),
     d(new Private)
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList groups = custom(QStringLiteral("GCALENDAR"), QStringLiteral("groupMembershipInfo")).split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
     const QStringList groups = custom(QStringLiteral("GCALENDAR"), QStringLiteral("groupMembershipInfo")).split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
     for (const QString &group : groups) {
         d->groups.insert(group, false);
     }
@@ -174,11 +166,7 @@ void Contact::addGroup(const QString &group)
 
     d->groups.insert(group, false);
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QStringList groups = custom(QStringLiteral("GCALENDAR"), QStringLiteral("groupMembershipInfo")).split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
     QStringList groups = custom(QStringLiteral("GCALENDAR"), QStringLiteral("groupMembershipInfo")).split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
     if (!groups.contains(group)) {
         groups.append(group);
     }
@@ -198,11 +186,7 @@ void Contact::setGroups(const QStringList &groups)
 
 QStringList Contact::groups() const
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    return custom(QStringLiteral("GCALENDAR"), QStringLiteral("groupMembershipInfo")).split(QLatin1Char(','), QString::SkipEmptyParts);
-#else
     return custom(QStringLiteral("GCALENDAR"), QStringLiteral("groupMembershipInfo")).split(QLatin1Char(','), Qt::SkipEmptyParts);
-#endif
 }
 
 void Contact::clearGroups()
@@ -267,19 +251,19 @@ QString Contact::IMSchemeToProtocolName(const QString& scheme)
 
 QString Contact::IMProtocolNameToScheme(const QString& protocolName)
 {
-    QString proto;
-    if (protocolName.toUpper() == QLatin1String("XMPP")) {
+    QString proto {protocolName.toUpper()};
+    if (proto == QLatin1String("XMPP")) {
         return SCHEME_URL + QLatin1String("JABBER");
-    } else if ((protocolName.toUpper() == QLatin1String("ICQ")) ||
-               (protocolName.toUpper() == QLatin1String("GOOGLE_TALK")) ||
-               (protocolName.toUpper() == QLatin1String("QQ")) ||
-               (protocolName.toUpper() == QLatin1String("SKYPE")) ||
-               (protocolName.toUpper() == QLatin1String("YAHOO")) ||
-               (protocolName.toUpper() == QLatin1String("MSN")) ||
-               (protocolName.toUpper() == QLatin1String("AIM")))
+    } else if ((proto == QLatin1String("ICQ")) ||
+               (proto == QLatin1String("GOOGLE_TALK")) ||
+               (proto == QLatin1String("QQ")) ||
+               (proto == QLatin1String("SKYPE")) ||
+               (proto == QLatin1String("YAHOO")) ||
+               (proto == QLatin1String("MSN")) ||
+               (proto == QLatin1String("AIM")))
     {
-        return SCHEME_URL + protocolName.toUpper();
-    } else if (protocolName.toUpper() == QLatin1String("GOOGLETALK")) {
+        return SCHEME_URL + proto;
+    } else if (proto == QLatin1String("GOOGLETALK")) {
         return SCHEME_URL + QStringLiteral("GOOGLE_TALK");
     }
 
