@@ -16,8 +16,6 @@
 
 #include <QNetworkRequest>
 #include <QNetworkReply>
-#include <QBuffer>
-#include <QImage>
 
 using namespace KGAPI2;
 
